function escvlops(X,y,prepro_method,nret)
% ESCVLOPS Shows a plot of Latent Variables vs. RMSECV to help the user to choose an 
% adequate number of latent variables to be used in the generation of the vectors in vectops (hOPS)
% Input: 
%         X (m,n): independent variables
%         y (m,1): dependent variable 
%         prepro_method : string containing the desired preprocessing method
%                          Mean center = 'mean', autoscale = 'auto', 
%                          none = 'none'
%          nret: number of samples to be removed during cross validation
% Output: 
%       Latent variables vs. RMSECV plot
%
% escvlops(X,y,prepro_method,nret)
%
% See also: VECTOPS, EXECOPS, SELVECTOPS, OPSWIZARD, OPSWIZARDGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 12/06
%  Checked on MATLAB 7 by RFT  13/12/06
%  Added support for cross validation by JPAM 14/12/06
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  -standard IO mods

[a,b] = size(X);

% A latent variable number is defined according to the number of rows in the matrix

aval = min(round(a/2),b);
if aval >= 15
    nvl = 15;
else
    nvl = aval;
end

if strcmp(lower(prepro_method),'mean')
    prepro_method = 2;
elseif strcmp(lower(prepro_method),'auto')
    prepro_method = 1;
elseif strcmp(lower(prepro_method),'none')
    prepro_method = 3;
end

PLSmodel = val_cruzada(X,y,nvl,prepro_method,prepro_method,nret); % Validao cruzada
    
plot(1:nvl,PLSmodel.RMSECV,'-o');
xlabel ('Latent variables')
ylabel ('RMSECV')
grid on
end