function result = execops(Xor,y,ind,jan,incr,p,prepro_method,nret)
% EXECOPS Executes OPS algorithm
% Input:
%          Xor(m,n): ordered independent variables
%          y(m,1): dependent variable
%          jan: scalar >=2, window of initial variables
%          incr: scalar >=1, increment of variables to be added to the window
%          ind: output from SELVECTOPS function
%          p(%): scalar >=1 and <=100. Percentage of ordered variables to be considered in the
%	 selection
%          nret: number of samples to be removed during cross validation
% Output:
%        Struct with the results obtained in each set
%
% result = execops(Xor,y,ind,jan,incr,p,prepro_method,nret)
%
%
% See also: SELVECTOPS, SELSETOPS, VECTOPS, VERTABOPS, OPSWIZARD, OPSWIZARDGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 12/06
%  Checked on MATLAB 7 by RFT  13/12/06
%  Added support for cross validation by JPAM 14/12/06
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  -standard IO mods

A1 = Xor(:,1:jan);
[a,b] = size(A1);
aval = min(round(a/2),b);
if aval >= 15
    npcs = 15;
else
    npcs = aval;
end

[m,n] = size(Xor);
if p < 10
    nv = round((10*n)/100);
elseif p > 100
    nv = n;
else
    nv = round((p*n)/100);
end
ftime = clock; % usado para medir o tempo total
time = clock;

if strcmp(lower(prepro_method),'mean')
    prepro_method = 2;
elseif strcmp(lower(prepro_method),'auto')
    prepro_method = 1;
elseif strcmp(lower(prepro_method),'none')
    prepro_method = 3;
end
PLSmodel = val_cruzada(A1,y,npcs,prepro_method,prepro_method,nret);
rmsecvout(1) = {PLSmodel.RMSECV};
rcvout(1) = {PLSmodel.rcv};
var_sel(1)={ind(1:jan)};

fprintf('Window %i:%i',1);
time(1) = etime(clock,time);
fprintf(' (%ss)\n',num2str(time(1),3));

i = 2;
tam = jan + incr;
while tam <= nv
    time = clock;
    A1 = Xor(:,1:tam);
    [a,b] = size(A1);
    aval = min(round(a/2),b);
    if aval >= 15
        npcs = 15;
    else
        npcs = aval;
    end
    PLSmodel = val_cruzada(A1,y,npcs,prepro_method,prepro_method,nret);
  
    rmsecvout(i) = {PLSmodel.RMSECV};     
    rcvout(i) = {PLSmodel.rcv};
    var_sel(i)={ind(1:tam)};
    tam = tam + incr;
    
    fprintf('Increment %i:%i',i);
    time(i) = etime(clock,time);
    fprintf(' (%ss)\n',num2str(time(i),3));
    
    i = i+1;
end
if (tam-incr) < nv
    time = clock;
    A1 = Xor(:,1:nv);
    [a,b] = size(A1);
    aval = min(round(a/2),b);
    if aval >= 15
        npcs = 15;
    else
        npcs = aval;
    end
    PLSmodel = val_cruzada(A1,y,npcs,prepro_method,prepro_method,nret);
    
    rmsecvout(i) = {PLSmodel.RMSECV};
    rcvout(i) = {PLSmodel.rcv};
    var_sel(i)={ind(1:nv)};
    
    fprintf('Increment %i:%i',i);
    time(i) = etime(clock,time);
    fprintf(' (%ss)\n',num2str(time(i),3));
    
    i = i+1;
end


% Full set
if p < 100
 [a,b] = size(Xor);
 aval = min(round(a/2),b);
 if aval >= 15
     npcs = 15;
 else
     npcs = aval;
 end
 PLSmodel = val_cruzada(Xor,y,npcs,prepro_method,prepro_method,nret);
 
 rmsecvout(i) = {PLSmodel.RMSECV};
 rcvout(i) = {PLSmodel.rcv};
 var_sel(i)={ind(1:n)};
 
 fprintf('Full set %i:%i',i);
 time(i) = etime(clock,time);
 fprintf(' (%ss)\n',num2str(time(i),3));
 i = i+1;
end

[u,h] = size(rmsecvout);
set = [1:h]';
rmsecv_b = zeros(h,1);
rcv_b = zeros(h,1);
nvl_b = zeros(h,1);
nvars = zeros(h,1);

for j = 1:h
    err = rmsecvout{j};           % vetor com os valores de rmsecv em i
    errn = err/norm(err,inf);
    q = rcvout{j};                % vetor com os valores de r em i
    [vars,ns] = size(var_sel{j}); % Conjunto de variveis
    par = q./errn;                % Parmetro
    [t,g] = sort(par);
    vl_opt1 = g(length(g)); % escolha do nmero de fatores timos
    % quanto menor o rmsecv, e maior o valor de q, maior ser o valor de 
    % par, portanto, o valor de vl  o ndice deste maior valor.
    vl = vl_opt1;
    rmsecv_b(j) = err(vl);
    rcv_b(j) = q(vl);
    nvl_b(j) = vl;
    nvars(j) = vars; 
end
fprintf('Total time %i:%i',i);
ftime(i) = etime(clock,ftime);
fprintf(' (%ss)\n',num2str(ftime(i),3));

resultab = [set nvars nvl_b rmsecv_b rcv_b];

txt = cell(0);
txt{end+1} = ('  ');
txt{end+1} = ('               Partial results              ');
txt{end+1} = ('  ');
txt{end+1} = ('   ----------------Results--------------    ');
txt{end+1} = ('   set.    nVar   nLV     RMSECV    rcv     ');
txt{end+1} = ('   -----   -----  -----   ------    ----    ');
format =      '   %3.0f     %3.0f    %3.0f     %1.4f  %0.3f';
for ii=1:h
    txt{end+1} = sprintf(format,resultab(ii,:));
end
txt{end+1} = ('   ______________________________________   ');
disp(sprintf('%s\n',txt{:}));

T = resultab;
pn = ((T(:,5)*norm(rmsecv_b,inf))./rmsecv_b);
pm = max(pn);
L = find(pn == pm);
sel = [T(L,1) T(L,2) T(L,3) T(L,4) T(L,5)];

txt = cell(0);
txt{end+1} = ('  ');
txt{end+1} = ('              Suggested result              ');
txt{end+1} = ('  ');
txt{end+1} = ('   --------------------------------------   ');
txt{end+1} = ('   set.    nVar    nLV     RMSECV   rcv     ');
txt{end+1} = ('   -----   -----   -----   ------   ----    ');
format =      '   %3.0f    %3.0f     %3.0f      %1.4f   %0.3f';
for ii=1:1
    txt{end+1} = sprintf(format,sel(ii,:));
end
txt{end+1} = ('   ______________________________________   ');
disp(sprintf('%s\n',txt{:}));

% Salvando os resultados

result.rmsecvout     =  [rmsecvout];
result.rcvout        =  [rcvout];
result.setvar        =  [var_sel];
result.Xor           =  [Xor];
result.y             =  [y];
result.prep_method   =  prepro_method;
result.nametab       =  {'conj' 'nVars' 'nVL' 'RMSECV' 'rcv'};
result.tabela        =  resultab;
result.tabsugest     =  sel;

% avaliao grfica

nvls = num2str(nvl_b); % string dos nmero de variveis latentes 
sets = num2str(set);   % string dos conjuntos de variveis
nvar = num2str(nvars); % string do nmero de variveis selecionadas em cada conjunto
                       % tamanho do vetor
nseta = length(nvars); % tamanho do vetor dos conjuntos de variveis
nsetb = (1:nseta);


figure
plot(nsetb,rmsecv_b,'-o')
text(nsetb+0.15,rmsecv_b,nvls)
grid on
ylabel ('RMSECV')
xlabel ('Set of variables')
holin(rmsecv_b(h),'-r')
text(min(set)+1,rmsecv_b(h),['rmsecv of all variables = ',num2str(rmsecv_b(h)),...
    '    nLV = ',num2str(nvl_b(h))],'verticalalignment','bottom','FontSize',12)