function [Xor,ind] = selvectops(X,vector)
% SELVECTOPS Performs the ordering of variables in X 
% according to the provided vector
% 
% Input:
%          X (m,n): independent variables matrix
%          vector (1,n) ou (n,1): informative vector
%          vector also can be the output of vectops function. In this case 
%          a message asking to the user select a vector will be shown in the screen
% Output:
%          Xor(m,n): Ordered matrix
%          ind(n,1): Vector containing the indexes of the original the variables in the
%	 original matrix
%
% [Xor,ind] = selvectops(X,vector);
%
% See also: VECTOPS, ESCVLOPS, EXECOPS, OPSWIZARD, OPSWIZARGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 12/06
%  Checked on MATLAB 7 by RFT  13/12/06
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  Added support for cross validation by JPAM 14/12/06
%  -standard IO mods

nstruc = isstruct(vector);
if nstruc == 1
    s = sprintf('Select the vector that will be used to perform the variable selection:\n1 - Regression vector\n2 - Correlogram\n3 - Product');
    disp(s);
    op = input('Opo: ');
    switch op
        case 1
            vector = vector.reg;
        case 2
            vector = vector.corr;
        case 3
            vector = vector.prod;
        otherwise
            display('Invalid option! Product vector will be used');
            vector = vector.prod;
    end
end
[m,n]=size(X);
vector = abs(vector); %somente os valores absolutos
[l,c] = size(vector);
if l == n & c == 1
    [vector,ind] = sort(vector,1,'descend');  % ordenao do vetor linha
elseif l == 1 & c == n
     [vector,ind] = sort(vector,2,'descend'); % ordenao do vetor coluna
else
    disp('the number of elements of vector must be the same number of columns in X')
    return
end


for i = 1:n
    Xor(:,i) = X(:,ind(i)); %a matriz  ordenada pelo vetor ordenado
end