function [result,varsels] = opswizard(X,y,nret,prepro_method)
% OPSWIZARD Executes OPS algorithm guiding the user with instructions in
% text mode. The input is required during the algorithm processing
%
% Input: 
%          X (m,n): independent variables matrix
%          y (m,1): dependent variable vector
%         prepro_method : string containing the desired preprocessing method
%                          Mean center = 'mean', autoscale = 'auto', 
%                          none = 'none'
%          default: 'auto'
%          nret: number of samples to be removed during cross validation
% Output:
%         result:  struct with the obtained models
%         varsels: struct with the variables selected by the algorithm
%                  and evaluations of the chosen model
%
% [result,varsels] = opswizard(X,y,nret,prepro_method);
%
% See also: VECTOPS, SELVECTOPS, EXECOPS, SELSETOPS, OPSWIZARDGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by JPAM  06/02/07
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  
%  -standard IO mods
close all
if nargin < 4
    prepro_method = questdlg('Which preprocessing method do you want to use?','Preprocessing','mean','auto','none','mean');
end
[vectors] = vectops(X,y,prepro_method,nret);
[Xor,ind] = selvectops(X,vectors);
jan = input('enter with the window size: ');
incr = input('enter with the increment size: ');
p = input('enter with the percentage of desired variables: ');
result = execops(Xor,y,ind,jan,incr,p,prepro_method,nret);
set = input('enter with the desired set : ');
varsels = selsetops(result,set,X,y,nret);