function B = opsimpls(X,Y,nvl);
% Algorithm that performs PLS regression
%
% Reference: de Jong S. SIMPLS: an alternative approach to partial least
% squares regression. Chemometrics and Intell. Lab. Syst. 18: 251-263, 1993.
%
% Input: 
%         X (n,px): independent variables matrix
%         Y (n,m): dependent variable vector
%         nvl: maximum number of latent variables to be computed
% Output: 
%         B (px,nvl): matrix with the regression vectors for each number of
%                     latent variables
% B = opsimpls(X,Y,nvl);

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  -standard IO mods

[n,px] = size(X); [n,m] = size(Y);   				
S=(Y'*X)'; 
if n > 3*px 
    XtX = X'*X;
else
    XtX = [];
end			
if nargin<3
    nvl=10; 
end
nvl = min([nvl px n-1]);        
T = zeros(n ,nvl); U = T;		
R = zeros(px,nvl); P = R; V = R;
C = zeros(m ,nvl); 
R2Y = zeros(1,nvl);
z = zeros(m,1); v = zeros(px,1);
if n>px, S0 = S; 
end 
StS = S'*S;				
nm1 = n-1;
tol = 0;
for a = 1:nvl
    StS = StS-z*z';
    [Q,LAMBDA] = eig(StS);
    [lambda,j] = max(diag(LAMBDA));
    q = Q(:,j(1));
    r = S*q;
    t = X*r;
    if isempty(XtX)
        p = (t'*X)'; 
    else p = XtX*r;
    end
    if n>px
        d = sqrt(r'*p/nm1); 
    else d = sqrt(t'*t/nm1); 
    end
  v = p-V(:,1:max(1,a-1))*(p'*V(:,1:max(1,a-1)))'; 
  v = v/sqrt(v'*v); 
  z = (v'*S)'; 
  S = S-v*z'; 
% salvando resultados
  V(:,a) = v;
  R(:,a) = r/d; 						
  P(:,a) = p/(d*nm1); 					
  T(:,a) = t/d;							
  U(:,a) = Y*q;							
  C(:,a) = q*(lambda(1)/(nm1*d)); 		
  R2Y(1,a) =  lambda(1)/d;				
  B(:,a) = R*C';
end
clear StS V LAMBDA Q p q r t v z;



