function [Xpreproc,media,desvio] = preprocessa(X,preproc)
% PREPROCESSA Performs the preprocessing of X matrix
%
% Input: 
%         X (m,n): matrix
%         preproc (1, 2 or 3): preprocessing method to be used
%         1 = autoscale; 2 = mean center; 3 = none
% Output: 
%         Xpreproc (m,n): preprocessed matrix
% media: line vector with the means of the columns in X
% desvio: line vector with the standard deviations of the columns in X
%
% [Xpreproc,media,desvio] = preprocessa(X,preproc)
%
% See also: PROCESSA, AUTOESCALA, CENTRA, VAL_CRUZADA

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by JPAM  06/02/07
%  -standard IO mods

switch preproc
    case 1
        [Xpreproc,media,desvio] = autoescala(X);
    case 2
        [Xpreproc,media,desvio] = centra(X);
    case 3
        Xpreproc = X;
        media = mean(X);
        desvio = std(X);
    otherwise
        display('Opo invlida! O autoescalamento ser usado');
        [Xpreproc,media,desvio] = autoescala(X);
end
