function vet = processa(X,media,desvio,preproc)
% PROCESSA Performs the processing of the X matrix according to the
% method chosen in preproc and the mean and standard deviation provided as input
% Function used in cross validation
%
% Input: 
%         X (m,n): matrix
%         preproc (1, 2 or 3): preprocessing method to be used
%         1 = autoscale; 2 = mean center; 3 = none
% 	media: line vector with the means of the columns in X
% 	desvio: line vector with the standard deviations of the columns in X
% Output: 
%         vet (m,n): processed matrix
%
% vet = processa(X,media,desvio,preproc)
%
% See also: PREPROCESSA, AUTOESCALA, CENTRA, VAL_CRUZADA

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by JPAM  06/02/07
%  -standard IO mods

[m,n] = size(X);
media = ones(m,1)*media;
desvio = ones(m,1)*desvio;
switch preproc
    case 1
        vet = (X-media);
        vet = vet./desvio;
    case 2
        vet = (X-media);
    otherwise
        vet = X;
end
