function mreescalada = reescala(M,media,desvio,preproc)
% REESCALA Performs the rescaling of the X matrix according to the
% method chosen in preproc and the mean and standard deviation provided as input
% Function used in cross validation in the prediction of the samples outside the model
%
% Input: 
%         X (m,n): matrix
%         preproc (1, 2 or 3): preprocessing method to be used
%         1 = autoscale; 2 = mean center; 3 = none
% 	media: line vector with the means of the columns in X
% 	desvio: line vector with the standard deviations of the columns in X
% Output: 
%         mreescalada (m,n): rescaled matrix
%
% mreescalada = reescala(M,media,desvio,preproc)
%
% See also: PREPROCESSA, AUTOESCALA, CENTRA, VAL_CRUZADA

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by JPAM  06/02/07
%  -standard IO mods

[m,n] = size(M);
switch preproc
    case 1
        mreescalada = M*desvio;
        mreescalada = media + mreescalada;
    case 2
        mreescalada = media + M;
    case 3
        mreescalada = M;
    otherwise
        mreescalada = M*desvio;
        mreescalada = media + mreescalada;
end