function PLSmodel = val_cruzada(X1,y,npcs,preprocx,preprocy,nret)
% VAL_CRUZADA Performs leave-N-out cross validation of a regression model
%
% Input: X (m,n): independent variables matrix
% 	   y (m,1): dependent variabels vector
% 	   npcs: maximum number of latent variables to be computed
% 	   preprocx (1, 2 or 3): preprocessing method to be used to the 
% 				independent variables
% 	   preprocy (1, 2 or 3): preprocessing method to be used to the 
% 				dependent variable
% 	   nret: number of samples to be removed in cross validation
% Output: PLSmodel: struct with the obtained PLS model
%
% PLSmodel = val_cruzada(X1,y,npcs,preprocx,preprocy,nret)
%
% See also: PREPROCESSA, PROCESSA, REESCALA, CORRELOGRAMA

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 02/07
%  Checked on MATLAB 7 by JPAM  06/02/07
%  -standard IO mods

[m,n] = size(X1);
[X1,y] = aleatoriza(X1,y);
nconj = floor(m/nret);
X = X1((nret+1):m,:);
[X,media,desvio] = preprocessa(X,preprocx);
yaux = y((nret+1):m,:);
[yaux,mediay,desvioy] = preprocessa(yaux,preprocy);
b = plskernel(X,yaux,npcs);
vet = processa(X1(1:nret,:),media,desvio,preprocx);
ycv(1:nret,:) = vet*b;
ycv(1:nret,:) = reescala(ycv(1:nret,:),mediay,desvioy,preprocy);
for i=2:nconj
    X = [X1(1:((i-1)*nret),:);X1((nret*i+1):m,:)];
    [X,media,desvio] = preprocessa(X,preprocx);
    yaux = [y(1:((i-1)*nret),:);y((nret*i+1):m,:)];
    [yaux,mediay,desvioy] = preprocessa(yaux,preprocy);
    b = plskernel(X,yaux,npcs);
    vet = processa(X1((nret*(i-1)+1):(nret*i),:),media,desvio,preprocx);
    ycv((nret*(i-1)+1):(nret*i),:) = vet*b;
    ycv((nret*(i-1)+1):(nret*i),:) = reescala(ycv((nret*(i-1)+1):(nret*i),:),mediay,desvioy,preprocy);
end
rest = m-(nconj*nret);
if rest~=0
    X = X1(1:m-rest,:);
    [X,media,desvio] = preprocessa(X,preprocx);
    yaux = y(1:m-rest,:);
    [yaux,mediay,desvioy] = preprocessa(yaux,preprocy);
    b = plskernel(X,yaux,npcs);
    vet = processa(X1(((m-rest)+1):m,:),media,desvio,preprocx);
    ycv(((m-rest)+1):m,:) = vet*b;
    ycv(((m-rest)+1):m,:) = reescala(ycv(((m-rest)+1):m,:),mediay,desvioy,preprocy);
end
for j=1:npcs
    press = sum((y-ycv(:,j)).^2);
    rmsecv(j) = sqrt(press/m);
    rcv(j) = correlograma(ycv(:,j),y);
end
PLSmodel.RMSECV = rmsecv;
PLSmodel.rcv = rcv;
PLSmodel.Ypred = ycv;

